@@ -282,13 +282,13 @@ pub mod named_transfer_fn {
 
     /// Rec. ITU-R BT.2100-2 perceptual quantization (PQ) system, value 16.
     pub const PQ: ColorSpaceTransferFn = ColorSpaceTransferFn {
-        g: -2.0,
-        a: -107.0 / 128.0,
-        b: 1.0,
-        c: 32.0 / 2523.0,
-        d: 2413.0 / 128.0,
-        e: -2392.0 / 128.0,
-        f: 8192.0 / 1305.0,
+        g: -5.0,
+        a: 203.0,
+        b: 0.0,
+        c: 0.0,
+        d: 0.0,
+        e: 0.0,
+        f: 0.0,
     };
 
     /// SMPTE ST 428-1, value 17.
@@ -304,14 +304,13 @@ pub mod named_transfer_fn {
     };
 
     /// Rec. ITU-R BT.2100-2 hybrid log-gamma (HLG) system, value 18.
-    #[allow(clippy::excessive_precision)]
     pub const HLG: ColorSpaceTransferFn = ColorSpaceTransferFn {
-        g: -3.0,
-        a: 2.0,
-        b: 2.0,
-        c: 1.0 / 0.178_832_77,
-        d: 0.284_668_92,
-        e: 0.559_910_73,
+        g: -6.0,
+        a: 203.0,
+        b: 1000.0,
+        c: 1.2,
+        d: 0.0,
+        e: 0.0,
         f: 0.0,
     };
 
